==> ElectricalWireSizes-0.1.28rc1.tar.gz: ElectricalWireSizes-0.1.28rc1/electricalwiresizes/bd.py <==
'''



██╗░░██╗███████╗██╗░░░░░███████╗░█████╗░████████╗██████╗░██╗░█████╗░
██║░██╔╝██╔════╝██║░░░░░██╔════╝██╔══██╗╚══██╔══╝██╔══██╗██║██╔══██╗
█████═╝░█████╗░░██║░░░░░█████╗░░██║░░╚═╝░░░██║░░░██████╔╝██║██║░░╚═╝
██╔═██╗░██╔══╝░░██║░░░░░██╔══╝░░██║░░██╗░░░██║░░░██╔══██╗██║██║░░██╗
██║░╚██╗███████╗███████╗███████╗╚█████╔╝░░░██║░░░██║░░██║██║╚█████╔╝
╚═╝░░╚═╝╚══════╝╚══════╝╚══════╝░╚════╝░░░░╚═╝░░░╚═╝░░╚═╝╚═╝░╚════╝░.

::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
| Web :  www.electricalwiresizes.org, 01/06/2022                         |            |
| Version : 0.1.28rc1                                                    |
| Autor : Marco Polo Jacome Toss                                         |
| License: GNU Affero General Public License v3 (GPL-3.0)                |
| Requires: Python >=3.5                                                 |
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

'''
dbConductorCu=[["14 AWG",10.171,0.1903,10.171,0.1903,10.171,0.2395,15,20,25,2.08],
["12 AWG",6.5617,0.1772,6.5617,0.1772,6.5617,0.2231,20,25,30,3.31],
["10 AWG",3.937,0.1640,3.937,0.1640,3.937,0.2067,30,35,40,5.261],
["8 AWG",2.5591,0.1706,2.5591,0.1706,2.5591,0.2133,40,50,55,8.367],
["6 AWG",1.6076,0.1673,1.6076,0.1673,1.6076,0.2100,55,65,75,13.301],
["4 AWG",1.0171,0.1575,1.0171,0.1575,1.0171,0.1969,70,85,95,21.201],
["2 AWG",0.6234,0.1476,0.6562,0.1476,0.6562,0.1870,95,115,130,33.620],
["1/0 AWG",0.3937,0.1444,0.4265,0.1444,0.3937,0.1804,125,150,170,53.49],
["2/0 AWG",0.3281,0.1411,0.3281,0.1411,0.3281,0.1772,145,175,195,67.43],
["3/0 AWG",0.2526,0.1378,0.269,0.1378,0.2592,0.1706,165,200,225,85.010],
["4/0 AWG",0.2034,0.1345,0.2198,0.1345,0.2067,0.1673,195,230,260,107.200],
["250 KCM",0.1706,0.1345,0.187,0.1345,0.1772,0.1706,215,255,290,127.001],
["300 KCM",0.1444,0.1345,0.1608,0.1345,0.1476,0.1673,240,285,320,152.001],
["350 KCM",0.1247,0.1312,0.1411,0.1312,0.128,0.1640,260,310,350,177.001],
["400 KCM",0.1083,0.1312,0.1247,0.1312,0.1148,0.1608,280,335,380,203.001],
["500 KCM",0.0886,0.1280,0.105,0.1280,0.0951,0.1575,320,380,430,253.001],
["600 KCM",0.0755,0.1280,0.0919,0.1280,0.082,0.1575,355,420,475,304.001],
["750 KCM",0.0623,0.1247,0.0787,0.1247,0.0689,0.1575,400,475,535,380.001],
["1000 KCM",0.0492,0.1214,0.0623,0.1214,0.0591,0.1509,455,545,615,507.001]]

dbConductorAl=[["6 AWG",2.658,0.1673,2.658,0.1673,2.658,0.2100,40,50,60,13.3],
["4 AWG",1.673,0.1575,1.673,0.1575,1.673,0.1969,55,65,75,21.201],
["2 AWG",1.050,0.1476,1.050,0.1476,1.050,0.1870,75,90,100,33.62],
["1/0 AWG",0.688,0.1444,0.689,0.1444,0.656,0.1804,100,120,135,53.49],
["2/0 AWG",0.525,0.1411,0.525,0.1411,0.525,0.1772,115,135,150,67.43],
["3/0 AWG",0.427,0.1378,0.427,0.1378,0.427,0.1706,130,155,175,85.01],
["4/0 AWG",0.328,0.1345,0.361,0.1345,0.328,0.1673,150,180,205,107.2],
["250 KCM",0.279,0.1345,0.295,0.1345,0.282,0.1706,170,205,230,127],
["300 KCM",0.233,0.1345,0.249,0.1345,0.236,0.1673,190,230,255,152],
["350 KCM",0.200,0.1312,0.217,0.1312,0.207,0.1640,210,250,280,177],
["400 KCM",0.178,0.1312,0.194,0.1312,0.180,0.1608,225,270,305,203],
["500 KCM",0.141,0.1280,0.158,0.1280,0.148,0.1575,260,310,350,253],
["600 KCM",0.118,0.1280,0.135,0.1280,0.124,0.1575,285,340,385,304],
["750 KCM",0.095,0.1247,0.112,0.1247,0.102,0.1575,320,385,435,380],
["1000 KCM",0.089,0.1214,0.082,0.1214,0.097,0.1509,375,445,500,507]]

dbConductorCuStd=[["14 AWG",10.7, 10.7, 10.7,15,20,25,2.08],
["12 AWG",6.73,6.73,6.73,20,25,30,3.31],
["10 AWG",4.226,4.226,4.226,30,35,40,5.261],
["8 AWG",2.653,2.653,2.653,40,50,55,8.367],
["6 AWG",1.671,1.671,1.671,55,65,75,13.3],
["4 AWG",1.053,1.053,1.053,70,85,95,21.15],
["2 AWG",0.661,0.661,0.661,95,115,130,33.62],
["1/0 AWG",0.415,0.415,0.415,125,150,170,53.49],
["2/0 AWG",0.329,0.329,0.329,145,175,195,67.49],
["3/0 AWG",0.261,0.261,0.261,165,200,225,85.01],
["4/0 AWG",0.205,0.205,0.205,195,230,260,107.2],
["250 KCM",0.1753,0.1753,0.1753,215,255,290,127],
["300 KCM",0.1463,0.1463,0.1463,240,285,320,152],
["350 KCM",0.1252,0.1252,0.1252,260,310,350,177],
["400 KCM",0.1084,0.1084,0.1084,280,335,380,203],
["500 KCM",0.0869,0.0869,0.0869,320,380,430,253],
["600 KCM",0.0732,0.0732,0.0732,350,420,475,304],
["700 KCM",0.0622,0.0622,0.0622,385,460,520,355],
["750 KCM",0.0579,0.0579,0.0579,400,475,535,380],
["800 KCM",0.0544,0.0544,0.0544,410,490,555,405],
["900 KCM",0.0481,0.0481,0.0481,435,520,585,456],
["1000 KCM",0.0434,0.0434,0.0434,455,545,615,507],
["1250 KCM",0.0347,0.0347,0.0347,495,590,665,633],
["1500 KCM",0.02814,0.02814,0.02814,525,625,705,760],
["1750 KCM",0.0241,0.0241,0.0241,545,650,735,887],
["2000 KCM",0.02109,0.02109,0.02109,555,665,750,1013]]

SITM=[0,15,20,30,40,50,60,70,80,90,100,110,125,150,175,200,225,250,300,350,400,450,500,600,700,800,1000,1200,1600,2000,2500,3000,4000,5000,6000]

==> ElectricalWireSizes-0.1.29.tar.gz: ElectricalWireSizes-0.1.29/electricalwiresizes/bd.py <==
'''
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
| Web :  www.electricalwiresizes.org, 07/07/2022                         |            |
| Version : 0.1.29                                                       |
| Autor : Marco Polo Jacome Toss                                         |
| License: GNU Affero General Public License v3 (GPL-3.0)                |
| Requires: Python >=3.5                                                 |
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

 ______ _           _        _           ___          ___           _____ _              
|  ____| |         | |      (_)         | \ \        / (_)         / ____(_)             
| |__  | | ___  ___| |_ _ __ _  ___ __ _| |\ \  /\  / / _ _ __ ___| (___  _ _______  ___ 
|  __| | |/ _ \/ __| __| '__| |/ __/ _` | | \ \/  \/ / | | '__/ _ \\___ \| |_  / _ \/ __|
| |____| |  __/ (__| |_| |  | | (_| (_| | |  \  /\  /  | | | |  __/____) | |/ /  __/\__ \
|______|_|\___|\___|\__|_|  |_|\___\__,_|_|   \/  \/   |_|_|  \___|_____/|_/___\___||___/

'''
dbConductorCu=[["14 AWG",10.171,0.1903,10.171,0.1903,10.171,0.2395,15,20,25,2.08],
["12 AWG",6.5617,0.1772,6.5617,0.1772,6.5617,0.2231,20,25,30,3.31],
["10 AWG",3.937,0.1640,3.937,0.1640,3.937,0.2067,30,35,40,5.261],
["8 AWG",2.5591,0.1706,2.5591,0.1706,2.5591,0.2133,40,50,55,8.367],
["6 AWG",1.6076,0.1673,1.6076,0.1673,1.6076,0.2100,55,65,75,13.301],
["4 AWG",1.0171,0.1575,1.0171,0.1575,1.0171,0.1969,70,85,95,21.201],
["2 AWG",0.6234,0.1476,0.6562,0.1476,0.6562,0.1870,95,115,130,33.620],
["1/0 AWG",0.3937,0.1444,0.4265,0.1444,0.3937,0.1804,125,150,170,53.49],
["2/0 AWG",0.3281,0.1411,0.3281,0.1411,0.3281,0.1772,145,175,195,67.43],
["3/0 AWG",0.2526,0.1378,0.269,0.1378,0.2592,0.1706,165,200,225,85.010],
["4/0 AWG",0.2034,0.1345,0.2198,0.1345,0.2067,0.1673,195,230,260,107.200],
["250 KCM",0.1706,0.1345,0.187,0.1345,0.1772,0.1706,215,255,290,127.001],
["300 KCM",0.1444,0.1345,0.1608,0.1345,0.1476,0.1673,240,285,320,152.001],
["350 KCM",0.1247,0.1312,0.1411,0.1312,0.128,0.1640,260,310,350,177.001],
["400 KCM",0.1083,0.1312,0.1247,0.1312,0.1148,0.1608,280,335,380,203.001],
["500 KCM",0.0886,0.1280,0.105,0.1280,0.0951,0.1575,320,380,430,253.001],
["600 KCM",0.0755,0.1280,0.0919,0.1280,0.082,0.1575,355,420,475,304.001],
["750 KCM",0.0623,0.1247,0.0787,0.1247,0.0689,0.1575,400,475,535,380.001],
["1000 KCM",0.0492,0.1214,0.0623,0.1214,0.0591,0.1509,455,545,615,507.001]]

dbConductorAl=[["6 AWG",2.658,0.1673,2.658,0.1673,2.658,0.2100,40,50,60,13.3],
["4 AWG",1.673,0.1575,1.673,0.1575,1.673,0.1969,55,65,75,21.201],
["2 AWG",1.050,0.1476,1.050,0.1476,1.050,0.1870,75,90,100,33.62],
["1/0 AWG",0.688,0.1444,0.689,0.1444,0.656,0.1804,100,120,135,53.49],
["2/0 AWG",0.525,0.1411,0.525,0.1411,0.525,0.1772,115,135,150,67.43],
["3/0 AWG",0.427,0.1378,0.427,0.1378,0.427,0.1706,130,155,175,85.01],
["4/0 AWG",0.328,0.1345,0.361,0.1345,0.328,0.1673,150,180,205,107.2],
["250 KCM",0.279,0.1345,0.295,0.1345,0.282,0.1706,170,205,230,127],
["300 KCM",0.233,0.1345,0.249,0.1345,0.236,0.1673,190,230,255,152],
["350 KCM",0.200,0.1312,0.217,0.1312,0.207,0.1640,210,250,280,177],
["400 KCM",0.178,0.1312,0.194,0.1312,0.180,0.1608,225,270,305,203],
["500 KCM",0.141,0.1280,0.158,0.1280,0.148,0.1575,260,310,350,253],
["600 KCM",0.118,0.1280,0.135,0.1280,0.124,0.1575,285,340,385,304],
["750 KCM",0.095,0.1247,0.112,0.1247,0.102,0.1575,320,385,435,380],
["1000 KCM",0.089,0.1214,0.082,0.1214,0.097,0.1509,375,445,500,507]]

dbConductorCuStd=[["14 AWG",10.7, 10.7, 10.7,15,20,25,2.08],
["12 AWG",6.73,6.73,6.73,20,25,30,3.31],
["10 AWG",4.226,4.226,4.226,30,35,40,5.261],
["8 AWG",2.653,2.653,2.653,40,50,55,8.367],
["6 AWG",1.671,1.671,1.671,55,65,75,13.3],
["4 AWG",1.053,1.053,1.053,70,85,95,21.15],
["2 AWG",0.661,0.661,0.661,95,115,130,33.62],
["1/0 AWG",0.415,0.415,0.415,125,150,170,53.49],
["2/0 AWG",0.329,0.329,0.329,145,175,195,67.49],
["3/0 AWG",0.261,0.261,0.261,165,200,225,85.01],
["4/0 AWG",0.205,0.205,0.205,195,230,260,107.2],
["250 KCM",0.1753,0.1753,0.1753,215,255,290,127],
["300 KCM",0.1463,0.1463,0.1463,240,285,320,152],
["350 KCM",0.1252,0.1252,0.1252,260,310,350,177],
["400 KCM",0.1084,0.1084,0.1084,280,335,380,203],
["500 KCM",0.0869,0.0869,0.0869,320,380,430,253],
["600 KCM",0.0732,0.0732,0.0732,350,420,475,304],
["700 KCM",0.0622,0.0622,0.0622,385,460,520,355],
["750 KCM",0.0579,0.0579,0.0579,400,475,535,380],
["800 KCM",0.0544,0.0544,0.0544,410,490,555,405],
["900 KCM",0.0481,0.0481,0.0481,435,520,585,456],
["1000 KCM",0.0434,0.0434,0.0434,455,545,615,507],
["1250 KCM",0.0347,0.0347,0.0347,495,590,665,633],
["1500 KCM",0.02814,0.02814,0.02814,525,625,705,760],
["1750 KCM",0.0241,0.0241,0.0241,545,650,735,887],
["2000 KCM",0.02109,0.02109,0.02109,555,665,750,1013]]

SITM=[0,15,20,30,40,50,60,70,80,90,100,110,125,150,175,200,225,250,300,350,400,450,500,600,700,800,1000,1200,1600,2000,2500,3000,4000,5000,6000]
